@@ -30,7 +30,6 @@ if sys.version_info >= (3, 3):
 else:
   from mock import patch # pylint: disable=import-error
 
-from six import string_types
 from copy import deepcopy
 from collections import OrderedDict
 
@@ -40,12 +39,13 @@ import cryptography.hazmat.primitives.hashes as hashing
 
 from securesystemslib import process
 from securesystemslib.gpg.functions import (create_signature, export_pubkey,
-    verify_signature)
+    verify_signature, export_pubkeys)
 from securesystemslib.gpg.util import (get_version, is_version_fully_supported,
     get_hashing_class, parse_packet_header, parse_subpacket_header)
 from securesystemslib.gpg.rsa import create_pubkey as rsa_create_pubkey
 from securesystemslib.gpg.dsa import create_pubkey as dsa_create_pubkey
 from securesystemslib.gpg.eddsa import create_pubkey as eddsa_create_pubkey
+from securesystemslib.gpg.eddsa import ED25519_SIG_LENGTH
 from securesystemslib.gpg.common import (parse_pubkey_payload,
     parse_pubkey_bundle, get_pubkey_bundle, _assign_certified_key_info,
     _get_verified_subkeys, parse_signature_packet)
@@ -55,7 +55,8 @@ from securesystemslib.gpg.constants import (SHA1, SHA256, SHA512,
 from securesystemslib.gpg.exceptions import (PacketParsingError,
     PacketVersionNotSupportedError, SignatureAlgorithmNotSupportedError,
     KeyNotFoundError, CommandError, KeyExpirationError)
-from securesystemslib.formats import GPG_PUBKEY_SCHEMA
+from securesystemslib.formats import (GPG_PUBKEY_SCHEMA,
+    ANY_PUBKEY_DICT_SCHEMA)
 
 
 @unittest.skipIf(not HAVE_GPG, "gpg not found")
@@ -63,7 +64,7 @@ class TestUtil(unittest.TestCase):
   """Test util functions. """
   def test_version_utils_return_types(self):
     """Run dummy tests for coverage. """
-    self.assertTrue(isinstance(get_version(), string_types))
+    self.assertTrue(isinstance(get_version(), str))
     self.assertTrue(isinstance(is_version_fully_supported(), bool))
 
   def test_get_hashing_class(self):
@@ -481,6 +482,8 @@ class TestGPGRSA(unittest.TestCase):
   unsupported_subkey_keyid = "611A9B648E16F54E8A7FAD5DA51E8CDF3B06524F"
   expired_key_keyid = "E8AC80C924116DABB51D4B987CB07D6D2C199C7C"
 
+  keyid_768C43 = "7B3ABB26B97B655AB9296BD15B0BD02E1C768C43"
+
   @classmethod
   def setUpClass(self):
     # Create directory to run the tests without having everything blow up
@@ -547,6 +550,17 @@ class TestGPGRSA(unittest.TestCase):
     self.assertDictEqual(key_data, key_data2)
 
 
+  def test_export_pubkeys(self):
+    """Test export multiple pubkeys at once. """
+    key_dict = export_pubkeys([self.default_keyid, self.keyid_768C43],
+        homedir=self.gnupg_home)
+
+    ANY_PUBKEY_DICT_SCHEMA.check_match(key_dict)
+    self.assertListEqual(
+        sorted([self.default_keyid.lower(), self.keyid_768C43.lower()]),
+        sorted(key_dict.keys()))
+
+
   def test_gpg_sign_and_verify_object_with_default_key(self):
     """Create a signature using the default key on the keyring """
 
@@ -764,5 +778,25 @@ class TestGPGEdDSA(unittest.TestCase):
     self.assertFalse(verify_signature(signature, key_data, wrong_data))
 
 
+  def test_verify_short_signature(self):
+    """Correctly verify a special-crafted short signature. """
+
+    test_data = b"hello"
+    signature_path = os.path.join(self.gnupg_home, "short.sig")
+
+    # Read special-crafted raw gpg signature that is one byte too short
+    with open(signature_path, "rb") as f:
+      signature_data = f.read()
+
+    # Check that the signature is padded upon parsing
+    # NOTE: The returned signature is a hex string and thus twice as long
+    signature = parse_signature_packet(signature_data)
+    self.assertTrue(len(signature["signature"]) == (ED25519_SIG_LENGTH * 2))
+
+    # Check that the signature can be successfully verified
+    key = export_pubkey(self.default_keyid, homedir=self.gnupg_home)
+    self.assertTrue(verify_signature(signature, key, test_data))
+
+
 if __name__ == "__main__":
   unittest.main()
